summaryrefslogtreecommitdiffstatshomepage
path: root/3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h
diff options
context:
space:
mode:
Diffstat (limited to '3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h')
-rw-r--r--3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h b/3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h
index 0df9aee13d7..4d30b926b8f 100644
--- a/3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h
+++ b/3rdparty/bgfx/3rdparty/spirv-tools/source/opt/vector_dce.h
@@ -94,12 +94,15 @@ class VectorDCE : public MemPass {
// Returns true if the result of |inst| is a vector or a scalar.
bool HasVectorOrScalarResult(const Instruction* inst) const;
// Returns true if the result of |inst| is a scalar.
bool HasVectorResult(const Instruction* inst) const;
- // Returns true if the result of |inst| is a vector.
+ // Returns true if the result of |inst| is a scalar.
bool HasScalarResult(const Instruction* inst) const;
+ // Returns the number of elements in the vector type with id |type_id|.
+ uint32_t GetVectorComponentCount(uint32_t type_id);
+
// Adds |work_item| to |work_list| if it is not already live according to
// |live_components|. |live_components| is updated to indicate that
// |work_item| is now live.
@@ -94,12 +94,15 @@ class VectorDCE : public MemPass {
// Returns true if the result of |inst| is a vector or a scalar.
bool HasVectorOrScalarResult(const Instruction* inst) const;
- // Returns true if the result of |inst| is a scalar.
+ // Returns true if the result of |inst| is a vector.
bool HasVectorResult(const Instruction* inst) const;